@@ -2,12 +2,13 @@ package clusterrbac
 
 import (
 	"context"
+	"github.com/open-cluster-management/multicloud-operators-foundation/pkg/helpers"
 	"reflect"
 
-	"github.com/stolostron/multicloud-operators-foundation/pkg/utils"
+	"github.com/open-cluster-management/multicloud-operators-foundation/pkg/utils"
 
 	clusterv1 "github.com/open-cluster-management/api/cluster/v1"
-	clusterv1beta1 "github.com/stolostron/multicloud-operators-foundation/pkg/apis/internal.open-cluster-management.io/v1beta1"
+	clusterv1beta1 "github.com/open-cluster-management/multicloud-operators-foundation/pkg/apis/internal.open-cluster-management.io/v1beta1"
 	rbacv1 "k8s.io/api/rbac/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -72,8 +73,7 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 	return nil
 }
 
-func (r *Reconciler) Reconcile(req ctrl.Request) (ctrl.Result, error) {
-	ctx := context.Background()
+func (r *Reconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error) {
 	clusterInfo := &clusterv1beta1.ManagedClusterInfo{}
 
 	err := r.client.Get(ctx, req.NamespacedName, clusterInfo)
@@ -169,7 +169,7 @@ func (r *Reconciler) createOrUpdateRole(clusterName string) error {
 // createOrUpdateRoleBinding create or update a role binding for a given cluster
 func (r *Reconciler) createOrUpdateRoleBinding(clusterName string) error {
 	roleName := roleName(clusterName)
-	acmRoleBinding := NewRoleBinding(roleName, clusterName).Groups(subjectPrefix + clusterName).BindingOrDie()
+	acmRoleBinding := helpers.NewRoleBinding(roleName, clusterName).Groups(subjectPrefix + clusterName).BindingOrDie()
 
 	// role and rolebinding have the same name
 	binding, err := r.kubeClient.RbacV1().RoleBindings(clusterName).Get(context.TODO(), roleName, metav1.GetOptions{})
